@@ -19,7 +19,7 @@ fn main() -> Result<()> {
     execute!(stdout, Hide, EnterAlternateScreen, EnableMouseCapture)?;
 
     let value = "Hello ".to_string();
-    let mut input = Input::default().with_cursor(value.len()).with_value(value);
+    let mut input = Input::default().with_value(value);
     backend::write(&mut stdout, input.value(), input.cursor(), (0, 0), 15)?;
     stdout.flush()?;
 
